@@ -1,9 +1,10 @@
+use anyhow::{anyhow, Result};
 use std::collections::HashSet;
 use std::path::Path;
 use std::str;
 
 use duct::cmd;
-use git2::{Config, Error, Repository};
+use git2::{Config, Repository};
 use log::{debug, trace, warn};
 
 /// Update old `req.key` config format to include remote name, i.e, `req.remote_name.key`
@@ -44,20 +45,18 @@ pub fn get_remote_url(remote: &str) -> String {
 }
 
 /// Get a value fom the repository config
-pub fn get_repo_info(repo_field: &str) -> Result<String, Error> {
-    let repo = Repository::open_from_env().expect("Couldn't find repository");
+pub fn get_repo_info(repo_field: &str) -> Result<String> {
+    let repo = Repository::open_from_env().map_err(|_| anyhow!("Couldn't find repository"))?;
     let cfg = repo.config().unwrap();
     cfg.get_string(repo_field)
+        .map_err(|err| anyhow!(err.to_string()))
 }
 
 /// Get a value for the given project-local git-req config
 pub fn get_config(field_name: &str, remote_name: &str) -> Option<String> {
     migrate_legacy(field_name, "origin");
     let key = format!("req.{}.{}", remote_name, field_name);
-    match get_repo_info(&key) {
-        Ok(val) => Some(val),
-        Err(_) => None,
-    }
+    get_repo_info(&key).ok()
 }
 
 /// Set a value for the project remote-local git-req configuration
@@ -81,10 +80,7 @@ pub fn delete_config(field_name: &str, remote_name: &str) {
 /// Get a value for the given project-local git-req config
 pub fn get_project_config(field_name: &str) -> Option<String> {
     let key = format!("req.{}", field_name);
-    match get_repo_info(&key) {
-        Ok(val) => Some(val),
-        Err(_) => None,
-    }
+    get_repo_info(&key).ok()
 }
 
 /// Set a value for the project-local git-req configuration. Consider using `set_config` unless
@@ -102,10 +98,7 @@ pub fn get_req_config(domain: &str, field: &str) -> Option<String> {
         &shellexpand::tilde("~/.gitreqconfig").to_string(),
     ))
     .unwrap();
-    match cfg.get_string(&format!("req.{}.{}", slug, field)) {
-        Ok(val) => Some(val),
-        Err(_) => None,
-    }
+    cfg.get_string(&format!("req.{}.{}", slug, field)).ok()
 }
 
 /// Set a value for the global git-req configuration
@@ -120,7 +113,7 @@ pub fn set_req_config(domain: &str, field: &str, value: &str) {
 }
 
 /// Clear the value for the lobal git-req configuration
-pub fn delete_req_config(domain: &str, field: &str) -> Result<(), Error> {
+pub fn delete_req_config(domain: &str, field: &str) -> Result<(), git2::Error> {
     let slug = slugify_domain(domain);
     let mut cfg = Config::open(&Path::new(
         &shellexpand::tilde("~/.gitreqconfig").to_string(),
@@ -130,16 +123,17 @@ pub fn delete_req_config(domain: &str, field: &str) -> Result<(), Error> {
 }
 
 /// Guess the name of the default remote
-#[allow(clippy::match_wild_err_arm)]
-pub fn guess_default_remote_name() -> Result<String, String> {
-    let repo = Repository::open_from_env().expect("Couldn't find repository");
-    let remotes = repo.remotes().expect("Couldn't fetch the list of remotes");
+pub fn guess_default_remote_name() -> Result<String> {
+    let repo = Repository::open_from_env().map_err(|_| anyhow!("Couldn't find repository"))?;
+    let remotes = repo
+        .remotes()
+        .map_err(|_| anyhow!("Couldn't fetch the list of remotes"))?;
     match remotes.len() {
-        0 => panic!("Could not find any remotes"),
+        0 => Err(anyhow!("Could not find any remotes")),
         1 => Ok(String::from(remotes.get(0).unwrap())),
         _ => match repo.find_remote("origin") {
             Ok(_) => Ok(String::from("origin")),
-            Err(_) => Err(String::from("No origin remote found")),
+            Err(_) => Err(anyhow!("No origin remote found")),
         },
     }
 }
@@ -150,7 +144,7 @@ pub fn checkout_branch(
     remote_branch_name: &str,
     local_branch_name: &str,
     is_virtual_remote_branch: bool,
-) -> Result<bool, String> {
+) -> Result<()> {
     let repo = Repository::open_from_env().expect("Couldn't find repository");
     let local_branch_name = match get_project_config("defaultremote") {
         Some(default_remote_name) => {
@@ -173,8 +167,8 @@ pub fn checkout_branch(
         Ok(_) => {
             debug!("Checking out branch: {}", local_branch_name);
             match cmd!("git", "checkout", &local_branch_name).run() {
-                Ok(_) => Ok(true),
-                Err(err) => Err(format!("Could not check out local branch: {}", err)),
+                Ok(_) => Ok(()),
+                Err(err) => Err(anyhow!("Could not check out local branch: {}", err)),
             }
         }
         Err(_) => {
@@ -187,7 +181,7 @@ pub fn checkout_branch(
                 &remote_branch_name
             });
             if cmd("git", fetch_args).run().is_err() {
-                return Err(format!(
+                return Err(anyhow!(
                     "Could not fetch remote branch '{}'",
                     remote_branch_name
                 ));
@@ -209,8 +203,8 @@ pub fn checkout_branch(
                 );
             };
             match cmd("git", checkout_args).run() {
-                Ok(_) => Ok(true),
-                Err(err) => Err(format!("Could not check out local branch: {}", err)),
+                Ok(_) => Ok(()),
+                Err(err) => Err(anyhow!("Could not check out local branch: {}", err)),
             }
         }
     }
