@@ -2,11 +2,13 @@
 mod git;
 mod remotes;
 
+use anyhow::Result;
 use clap::{crate_authors, crate_version, App, AppSettings, ArgMatches, YamlLoader};
 use colored::*;
 use git2::ErrorCode;
 use lazy_static::lazy_static;
 use log::{debug, error, info, trace};
+use logchop::*;
 use std::io::{self, stdin, stdout, Cursor, Write};
 use std::{env, include_str, process};
 use tabwriter::TabWriter;
@@ -22,27 +24,24 @@ lazy_static! {
 }
 
 /// Get the remote for the current project
-fn get_remote(remote_name: &str, fetch_api_key: bool) -> Result<Box<dyn remotes::Remote>, String> {
+fn get_remote(remote_name: &str, fetch_api_key: bool) -> Result<Box<dyn remotes::Remote>> {
     let remote_url = git::get_remote_url(remote_name);
     remotes::get_remote(remote_name, &remote_url, !fetch_api_key)
 }
 
 /// Get the remote, fail hard otherwise
 fn get_remote_hard(remote_name: &str, fetch_api_key: bool) -> Box<dyn remotes::Remote> {
-    match get_remote(remote_name, fetch_api_key) {
-        Ok(x) => x,
-        Err(error) => {
-            eprintln!(
-                "{}",
-                format!(
-                    "There was a problem finding the remote Git repo: {}",
-                    &error
-                )
-                .red()
-            );
-            process::exit(1);
-        }
-    }
+    get_remote(remote_name, fetch_api_key).unwrap_or_else(|error| {
+        eprintln!(
+            "{}",
+            format!(
+                "There was a problem finding the remote Git repo: {}",
+                &error
+            )
+            .red()
+        );
+        process::exit(1);
+    })
 }
 
 /// Check out the branch corresponding to the MR ID and the remote's name
@@ -50,38 +49,32 @@ fn checkout_mr(remote_name: &str, mr_id: i64) {
     info!("Getting MR: {}", mr_id);
     let mut remote = get_remote_hard(remote_name, true);
     debug!("Found remote: {}", remote);
-    let remote_branch_name = match remote.get_remote_req_branch(mr_id) {
-        Ok(name) => name,
-        Err(error) => {
-            eprintln!(
-                "{}",
-                format!(
-                    "There was a problem ascertaining the branch name: {}",
-                    &error
-                )
-                .red()
-            );
-            process::exit(1);
-        }
-    };
+    let remote_branch_name = remote.get_remote_req_branch(mr_id).unwrap_or_else(|error| {
+        eprintln!(
+            "{}",
+            format!(
+                "There was a problem ascertaining the branch name: {}",
+                &error
+            )
+            .red()
+        );
+        process::exit(1);
+    });
     debug!("Got remote branch name: {}", remote_branch_name);
-    match git::checkout_branch(
+    git::checkout_branch(
         remote_name,
         &remote_branch_name,
         &remote.get_local_req_branch(mr_id).unwrap(),
         remote.has_virtual_remote_branch_names(),
-    ) {
-        Ok(_) => {
-            info!("Done!");
-        }
-        Err(error) => {
-            eprintln!(
-                "{}",
-                format!("There was an error checking out the branch: {}", &error).red()
-            );
-            process::exit(1)
-        }
-    };
+    )
+    .info_ok("Done")
+    .unwrap_or_else(|err| {
+        eprintln!(
+            "{}",
+            format!("There was an error checking out the branch: {}", err).red()
+        );
+        process::exit(1)
+    });
 }
 
 /// Clear the API key for the current domain
@@ -179,39 +172,32 @@ fn generate_completion(app: &mut App, shell_name: &str) {
 
 /// Get the name of the remote to use for the operation
 fn get_remote_name(matches: &ArgMatches) -> String {
-    let default_remote_name = match git::get_project_config("defaultremote") {
-        Some(remote_name) => remote_name,
-        None => {
-            let new_remote_name = match git::guess_default_remote_name() {
-                Ok(guessed) => guessed,
-                Err(_) => {
-                    let mut new_remote_name = String::new();
-                    println!("Multiple remotes detected. Enter the name of the default one.");
-                    for remote in git::get_remotes() {
-                        println!(" * {}", remote);
-                    }
-                    print!("Remote name: ");
-                    let _ = stdout().flush();
-                    stdin()
-                        .read_line(&mut new_remote_name)
-                        .expect("Did not input a name");
-                    trace!("New remote: {}", &new_remote_name);
-                    if !git::get_remotes().contains(new_remote_name.trim()) {
-                        panic!("Invalid remote name provided")
-                    }
-                    new_remote_name
-                }
-            };
-            git::set_project_config("defaultremote", &new_remote_name);
+    let default_remote_name = git::get_project_config("defaultremote").unwrap_or_else(|| {
+        let new_remote_name = git::guess_default_remote_name().unwrap_or_else(|_| {
+            let mut new_remote_name = String::new();
+            println!("Multiple remotes detected. Enter the name of the default one.");
+            for remote in git::get_remotes() {
+                println!(" * {}", remote);
+            }
+            print!("Remote name: ");
+            let _ = stdout().flush();
+            stdin()
+                .read_line(&mut new_remote_name)
+                .expect("Did not input a name");
+            trace!("New remote: {}", &new_remote_name);
+            if !git::get_remotes().contains(new_remote_name.trim()) {
+                panic!("Invalid remote name provided")
+            }
             new_remote_name
-        }
-    };
+        });
+        git::set_project_config("defaultremote", &new_remote_name);
+        new_remote_name
+    });
     // Not using Clap's default_value because of https://github.com/clap-rs/clap/issues/1140
-    String::from(
-        matches
-            .value_of("REMOTE_NAME")
-            .unwrap_or(&default_remote_name),
-    )
+    matches
+        .value_of("REMOTE_NAME")
+        .unwrap_or(&default_remote_name)
+        .to_string()
 }
 
 /// Get the Clap app for CLI matching et al.
